# jaeger-idl [![Build Status][ci-img]][ci]

A set of shared data model definitions used by Jaeger components.

## Contributing

See [CONTRIBUTING](./CONTRIBUTING.md).

## License
  
[Apache 2.0 License](./LICENSE).


[ci-img]: https://travis-ci.org/jaegertracing/jaeger-idl.svg?branch=master
[ci]: https://travis-ci.org/jaegertracing/jaeger-idl
